# STRENC : A String Encode/Decoder

[![PyPI version](https://badge.fury.io/py/strenc.svg)](https://badge.fury.io/py/strenc) [![Downloads](https://pepy.tech/badge/strenc)](https://pepy.tech/project/strenc)


[**PyPi Link**](https://pypi.org/project/strenc/)



*v0.1.0 and v0.1.1 can be found at[TestPyPi](https://test.pypi.org/project/strenc/)*

***Please note that strenc is currently under devolpement***

## What is strenc?

Strenc , or String(str)Encoder(enc) , is a pip package that will encode and decode a piece of string into cryptic message and to normal text.

## Why is it 'customizable'?

We have a command line tool added with the package , that will help you create keys , check which character is replaced by which and change the keys.


******


### How to install strenc
If you have python installed , run this from your command prompt:
```batch 
pip install strenc
```

**Errors**

1. 'pip' is not recognized as an internal or external command operable program or batch file.
*Solution* : Check if python is in your ```PATH``` variable.



